@@ -18,8 +18,12 @@ import org.jetbrains.intellij.platform.gradle.TestFrameworkType
 
 // https://github.com/JetBrains/intellij-platform-gradle-plugin/releases
 plugins {
-  id("org.jetbrains.intellij.platform") version "2.9.0"
-  kotlin("jvm") version "2.2.0"
+  id("org.jetbrains.intellij.platform") version "2.10.2"
+  // See https://plugins.jetbrains.com/docs/intellij/using-kotlin.html#bundled-stdlib-versions
+  // This version of Kotlin will crash if your Gradle daemon is running under Java 25 (even if that
+  // isn't the JDK you're using to compile). So make sure to update JAVA_HOME and then
+  // `./gradlew --stop`
+  kotlin("jvm") version "2.0.21"
 }
 
 repositories {
@@ -29,10 +33,13 @@ repositories {
 }
 
 // https://github.com/google/google-java-format/releases
-val googleJavaFormatVersion = "1.29.0"
-val pluginPatchVersion = "1"
+val googleJavaFormatVersion = "1.31.0"
+val pluginPatchVersion = "0"
 
 java {
+  toolchain {
+    languageVersion = JavaLanguageVersion.of(21)
+  }
   sourceCompatibility = JavaVersion.VERSION_21
   targetCompatibility = JavaVersion.VERSION_21
 }
@@ -44,7 +51,7 @@ intellijPlatform {
     name = "google-java-format"
     version = "${googleJavaFormatVersion}.${pluginPatchVersion}"
     ideaVersion {
-      sinceBuild = "243"
+      sinceBuild = "242"
       untilBuild = provider { null }
     }
   }
